pub async fn ipc_face_connect(id: FaceId, path: &str) -> Result<IpcFace>Expand description
Connect to the IPC socket at path and return an IpcFace.
On Unix, path is a filesystem path to a Unix domain socket.
On Windows, path is a named pipe path such as \\.\pipe\ndn.